CSS
===

All Joyous CSS classes begin with the prefix ``joy-`` and try to follow the BEM protocol of ``block__element--modifier``.

Blocks
------
.. code-block:: css

  .joy-overlay
  .joy-popup
  .joy-content
  .joy-title
  .joy-cal
  .joy-cal-list
  .joy-minical
  .joy-this-week
  .joy-view-choices
  .joy-days-events
  .joy-export
  .joy-ev-item
  .joy-field
  .joy-img-link
  .joy-img
  .joy-ev-who
  .joy-ev-when
  .joy-ev-from-when
  .joy-ev-to-when
  .joy-ev-next-on
  .joy-ev-where
  .joy-ev-website
  .joy-ev-details
  .joy-ev-extra
  .joy-ev-status
  .joy-ev-related
  .joy-grp-list
  .joy-pg
  .joy-rr

Elements
--------
.. code-block:: css

  .joy-title__link
  .joy-popup__outer
  .joy-popup__content
  .joy-popup__close
  .joy-view-choices__link
  .joy-cal__head
  .joy-cal__headings
  .joy-cal__heading
  .joy-cal__period-heading
  .joy-cal__period-ctrl
  .joy-cal__month-name
  .joy-cal__week-name
  .joy-cal__year-number
  .joy-cal__weekdays
  .joy-cal__weekday
  .joy-cal__body
  .joy-cal__week
  .joy-cal__no-day
  .joy-cal__day
  .joy-cal__read-more
  .joy-cal__day-title
  .joy-cal__date
  .joy-cal__holiday-name
  .joy-minical__head
  .joy-minical__headings
  .joy-minical__heading
  .joy-minical__month-heading
  .joy-minical__month-name
  .joy-minical__year-number
  .joy-minical__weekdays
  .joy-minical__weekday
  .joy-minical__body
  .joy-minical__week
  .joy-minical__day
  .joy-minical__no-day
  .joy-minical__day-title
  .joy-minical__date
  .joy-this-week__title
  .joy-this-week__events
  .joy-this-week__day
  .joy-this-week__day-title
  .joy-this-week__date
  .joy-this-week__weekday
  .joy-this-week__holiday-name
  .joy-this-week__days-events
  .joy-this-week__cal
  .joy-this-week__cal-link
  .joy-days-events__event
  .joy-days-events__event-time
  .joy-days-events__event-title
  .joy-days-events__event-text
  .joy-img-link__img
  .joy-img__img
  .joy-ev-who__link
  .joy-ev-to-when__link
  .joy-ev-where__map-link
  .joy-ev-website__link
  .joy-ev-related__item
  .joy-ev-related__link
  .joy-ev-related__overrides
  .joy-pg__page
  .joy-pg__ctrl
  .joy-pg__num
  .joy-rr__advanced-repeat
  .joy-rr__advanced-monthly-repeat
  .joy-rr__advanced-weekly-repeat
  .joy-rr__advanced-yearly-repeat
  .joy-rr__day-choice
  .joy-rr__days-input
  .joy-rr__short-input
  .joy-rr__months-input
  .joy-rr__freq-choice
  .joy-rr__half-field
  .joy-rr__double-field
  .joy-rr__ical-value
  .joy-rr__interval-num
  .joy-rr__interval-units-days
  .joy-rr__interval-units-months
  .joy-rr__interval-units-weeks
  .joy-rr__interval-units-years
  .joy-rr__months
  .joy-rr__ord-choice
  .joy-rr__primary
  .joy-rr__secondary
  .joy-rr__show-advanced
  .joy-rr__show-advanced-cbx
  .joy-rr__simple-repeat
  .joy-rr__start-date
  .joy-rr__until-date
  .joy-rr__weekdays

Modifiers
---------
.. code-block:: css

  .joy-title--page
  .joy-title--list
  .joy-title--item
  .joy-cal--weekly
  .joy-cal--monthly
  .joy-cal__weekday--sun
  .joy-cal__day--today
  .joy-cal__day--yesterday
  .joy-cal__day--lastweek
  .joy-cal__day--first
  .joy-cal__day--last
  .joy-cal__day--has-events
  .joy-cal__date--holiday
  .joy-cal__date--sun
  .joy-minical__weekday--sun
  .joy-minical__day--today
  .joy-minical__date--holiday
  .joy-minical__date--sun
  .joy-minical__date--event-link
  .joy-minical__date--event
  .joy-this-week__day--in-past
  .joy-this-week__day--today
  .joy-days-events__event--continues
  .joy-cal-list--upcoming
  .joy-cal-list--past
  .joy-cal-list--day
  .joy-pg__ctrl--disabled
  .joy-pg__num--active
